/**
 * 工具类
 *
 * @author luqs
 * @version v1.0.0
 */
var CommonUtils = {
    /**
     * 判断值是否为空
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    isEmpty: function (arg) {
        var protoType = this.protoType(arg);
        return (protoType === 'Undefined' || protoType === 'Null' || "" === arg + '');
    },
    /**
     * 判断值是否非空
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    isNotEmpty: function (arg) {
        return !this.isEmpty(arg);
    },
    /**
     * 判断值是否为空
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    isBlank: function (arg) {
        var protoType = this.protoType(arg);
        return protoType === 'Undefined' || protoType === 'Null' || ("" === (arg + '').trim());
    },
    /**
     * 判断值是否非空
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    isNotBlank: function (arg) {
        return !this.isBlank(arg);
    },
    /**
     * 判断是否空对象
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    isEmptyObject: function (arg) {
        var protoType = this.protoType(arg);
        if (protoType === 'Undefined' || protoType === 'Null') {
            return true;
        }
        return this.toJsonStr(arg) === '{}';
    },
    /**
     * 判断是否非空对象
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    isNotEmptyObject: function (arg) {
        return !this.isEmptyObject(arg);
    },
    /**
     * 判断值是否为整数
     * @param {string}arg 参数
     * @returns {boolean}
     */
    isInt: function (arg) {
        var reg = /^[-\+]?\d+$/;
        return reg.test(arg);
    },
    /**
     * 判断值是否为数值
     * @param {string}arg 参数
     * @returns {boolean}
     */
    isFloat: function (arg) {
        if (this.isBlank(arg)) {
            return false;
        }
        var reg = /^[-,+]?[1-9]\d*[.]?\d*|0\.\d*[1-9]\d*$/;
        return reg.test(arg);
    },
    /**
     * 默认值
     * @param {String|Object}arg 参数
     * @param {string}defaultVal 默认值
     * @returns {string}
     */
    defaultString: function (arg, defaultVal) {
        return this.isBlank(arg) ? (this.isEmpty(defaultVal) ? "" : defaultVal) : arg;
    },
    /**
     * 默认数值
     * @param {Object}arg 参数
     * @param {number}defaultVal 默认值
     * @returns {string}
     */
    defaultNum: function (arg, defaultVal) {
        return this.isBlank(arg) ? (this.isEmpty(defaultVal) ? "" : defaultVal) : arg;
    },
    /**
     * 序列化
     * @param {Object}arg 参数
     * @returns {string}
     */
    toJsonStr: function (arg) {
        try {
            return JSON.stringify(arg);
        } catch (e) {
            console.error("参数：【" + arg + "】，序列化出现异常：" + e);
            return "";
        }
    },
    /**
     * 获取集合个数
     * @param {Array}arg 参数
     * @returns {number}
     */
    size: function (arg) {
        var protoType = this.protoType(arg);
        if (protoType === 'Undefined' || protoType === 'Null') {
            return 0;
        }
        return arg.length;
    },
    /**
     * 是否包含
     * @param {Array}array 集合
     * @param {Object}arg 参数
     * @returns {boolean}
     */
    contain: function (array, arg) {
        var protoType = this.protoType(array);
        if (protoType === 'Array' && this.size(array) > 0) {
            for (var i = 0; i < array.length; i++) {
                if (array[i] === arg) {
                    return true;
                }
            }
        }
        return false;
    },
    /**
     * 不存在则添加
     * @param {Array}array 集合
     * @param {Object}arg 参数
     * @returns {array}
     */
    addIfNotExist: function (array, arg) {
        var protoType = this.protoType(array);
        if (protoType === 'Array' && !this.contain(array, arg)) {
            array.push(arg);
        }
        return array;
    },
    /**
     * 截取日期
     * @param {string}arg 参数，格式：yyyy-MM-dd HH:mm:ss
     * @returns {string}
     */
    subDate: function (arg) {
        if (this.isBlank(arg)) {
            return "";
        }
        return arg.substr(0, 10);
    },
    /**
     * 截取时间
     * @param {string}arg 参数，格式：yyyy-MM-dd HH:mm:ss
     * @returns {string}
     */
    subTime: function (arg) {
        if (this.isBlank(arg)) {
            return "";
        }
        return arg.substr(11);
    },
    /**
     * 获取星期
     * @param {string}arg 参数，格式：yyyy-MM-dd HH:mm:ss
     * @param {string}prefix 前缀，如：星期、周
     * @return {string}
     */
    getWeekDay: function (arg, prefix) {
        if (this.isBlank(arg)) {
            return "";
        }
        try {
            var date = new Date(arg);
            var week = ["日", "一", "二", "三", "四", "五", "六"];
            return this.defaultString(prefix) + week[date.getDay()];
        } catch (e) {
            console.error("时间参数：【" + arg + "】，获取星期出现异常：" + e);
            return "";
        }
    },
    /**
     * 格式化时间
     * @param {string|Date}arg 参数，格式：yyyy-MM-dd HH:mm:ss
     * @param format{string} 格式，如：星期、周
     * @return {string}
     */
    formatDateTime: function (arg, format) {
        var date;
        if ('String' === this.protoType(arg) && this.isNotBlank(arg)) {
            try {
                date = new Date(arg);
            } catch (e) {
                console.error("时间参数：【" + arg + "】，格式化时间出现异常：" + e);
                return "";
            }
        } else if ('Date' === this.protoType(arg)) {
            date = arg;
        } else {
            return "";
        }

        // 年，4位数字，如：2019
        var fullYear = date.getFullYear;
        // 月，0 ~ 11，如：1
        var month = date.getMonth();
        // 日，1 ~ 31，如：1
        var day = date.getDate();
        // 时，0 ~ 23，如：5
        var hour = date.getHours();
        // 分，0 ~ 59，如：2
        var minute = date.getMinutes();
        // 秒，0 ~ 59，如：25
        var second = date.getSeconds();

        if (this.isBlank(format)) {
            return fullYear + "-" + this.completeTimePlaceholder(month + 1) + "-" + this.completeTimePlaceholder(day)
                + " " + this.completeTimePlaceholder(hour) + ":" + this.completeTimePlaceholder(minute) + ":" + this.completeTimePlaceholder(second)
        }
        return format.replace('yyyy', fullYear).replace("yy", fullYear.toString().substr(2))
            .replace('MM', this.completeTimePlaceholder(month + 1)).replace("M", month + 1)
            .replace('dd', this.completeTimePlaceholder(day)).replace('d', day)
            .replace('HH', this.completeTimePlaceholder(hour)).replace('H', hour)
            .replace('mm', this.completeTimePlaceholder(minute)).replace('m', minute)
            .replace('ss', this.completeTimePlaceholder(second)).replace('s', second);

    },
    /**
     * 补全时间占位
     *
     * @param {number}arg
     * @return {string}
     */
    completeTimePlaceholder: function (arg) {
        if (arg >= 0 && arg < 10) {
            return "0" + arg;
        }
        return '' + arg;
    },
    /**
     * 判断具体的对象类型，如：String、Number、Array、Date、Object、Null、Undefined、RegExg、Function
     * <br/><strong>注：无法判断自定义对象类型</strong>
     * @param arg 参数
     * @return {string}
     */
    protoType: function (arg) {
        return Object.prototype.toString.call(arg).replace("[object ", "").replace("]", "");
    }

};